.. image:: /docs/figures/aurora_logo.png
   :width: 900
   :alt: AURORA

|

Aurora is a Python library for processing natural source electromagnetic data. It uses MTH5 formatted Magnetotelluric data and a configuration file as inputs and generates transfer functions that can be formatted as EMTF XML or other output formats. 

Documentation for the Aurora project can be found at http://simpeg.xyz/aurora/
